yakumo.neutron.v2.vpn.ipsec_policy

Package yakumo :: Package neutron :: Package v2 :: Package vpn :: Module ipsec_policy |
[hide private]
[frames] | no frames]

# Module ipsec_policy

source code

Resource class and its manager for VPN IPSec policies in Networking V2 API

Classes | [hide private]
| Resource Resource class for VPN IPSec policies in Networking V2 API
| Manager Manager class for VPN IPSec policies in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2.vpn``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('auth_algorithm', 'auth_algorithm',
       mapper.Noop), ('encryption_algorithm', 'encryption_algorithm', mapper
      .Noop), ('pfs', 'pfs', mapper.Noop), ('lifetime', 'lifetime', mapper.N
      oop), ('encapsulation_mode', 'encapsulation_mode', mapper.Noop), ('tra
      nsform_protocol', 'transform_protocol', mapper.Noop), ('project', 'ten
      ant_id', mapper.Resource('project')),]